import { Link } from "wouter";
import { Card, CardContent } from "@/components/ui/card";
import { Badge } from "@/components/ui/badge";
import SustainabilityRating from "./sustainability-rating";
import { Star } from "lucide-react";
import type { ProductWithCategory } from "@shared/schema";

interface ProductCardProps {
  product: ProductWithCategory;
}

export default function ProductCard({ product }: ProductCardProps) {
  const avgRating = product.reviews.length > 0 
    ? product.reviews.reduce((sum, review) => sum + review.rating, 0) / product.reviews.length 
    : 0;

  return (
    <Link href={`/products/${product.slug}`}>
      <Card className="product-card-hover cursor-pointer overflow-hidden group h-full">
        <div className="relative">
          <img 
            src={product.imageUrl} 
            alt={product.name}
            className="w-full h-48 object-cover group-hover:scale-105 transition-transform duration-300"
          />
          <div className="absolute top-3 right-3">
            <SustainabilityRating rating={product.sustainabilityRating} size="sm" />
          </div>
        </div>
        <CardContent className="p-4">
          <div className="flex items-center justify-between mb-2">
            <Badge variant="secondary" className="bg-green-100 text-green-800 text-xs">
              {product.category.name}
            </Badge>
          </div>
          
          <h3 className="font-semibold text-gray-900 mb-2 line-clamp-2">
            {product.name}
          </h3>
          
          <p className="text-gray-600 text-sm mb-3 line-clamp-2">
            {product.shortDescription}
          </p>
          
          <div className="flex items-center justify-between">
            <div className="flex items-center text-sm text-gray-500">
              <Star className="h-4 w-4 text-yellow-500 mr-1" />
              <span>{avgRating > 0 ? avgRating.toFixed(1) : 'No reviews'}</span>
              {product.reviews.length > 0 && (
                <span className="ml-1">({product.reviews.length})</span>
              )}
            </div>
            <span className="font-bold text-green-600">${product.price}</span>
          </div>
        </CardContent>
      </Card>
    </Link>
  );
}
